@@ -2,7 +2,4 @@ from jsonrequester import JsonRequester
 
 requester = JsonRequester('http://localhost:5000')
 
-print requester.post('/record', {
-    'type': 'test',
-    'priority': 'critical',
-})
+print requester.post('/record', {'type': 'test'})
